gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r28021 - in gnunet/src: identity include


From: gnunet
Subject: [GNUnet-SVN] r28021 - in gnunet/src: identity include
Date: Sun, 14 Jul 2013 21:25:22 +0200

Author: grothoff
Date: 2013-07-14 21:25:22 +0200 (Sun, 14 Jul 2013)
New Revision: 28021

Modified:
   gnunet/src/identity/gnunet-service-identity.c
   gnunet/src/identity/identity_api.c
   gnunet/src/include/gnunet_identity_service.h
Log:
-renaming pseudonym to ego in identity service

Modified: gnunet/src/identity/gnunet-service-identity.c
===================================================================
--- gnunet/src/identity/gnunet-service-identity.c       2013-07-14 19:15:32 UTC 
(rev 28020)
+++ gnunet/src/identity/gnunet-service-identity.c       2013-07-14 19:25:22 UTC 
(rev 28021)
@@ -20,27 +20,16 @@
 
 /**
  * @file identity/gnunet-service-identity.c
- * @brief network size estimation service
- * @author Nathan Evans
+ * @brief identity (management_ service
  * @author Christian Grothoff
  *
- * The purpose of this service is to estimate the size of the network.
- * Given a specified interval, each peer hashes the most recent
- * timestamp which is evenly divisible by that interval.  This hash is
- * compared in distance to the peer identity to choose an offset.  The
- * closer the peer identity to the hashed timestamp, the earlier the
- * peer sends out a "nearest peer" message.  The closest peer's
- * message should thus be received before any others, which stops
- * those peer from sending their messages at a later duration.  So
- * every peer should receive the same nearest peer message, and from
- * this can calculate the expected number of peers in the network.
+ * The purpose of this service is to manage private keys that
+ * represent the various egos/pseudonyms/identities of a GNUnet user.
  */
 #include "platform.h"
-#include <math.h>
 #include "gnunet_util_lib.h"
 #include "gnunet_constants.h"
 #include "gnunet_protocols.h"
-#include "gnunet_signatures.h"
 #include "gnunet_statistics_service.h"
 #include "gnunet_identity_service.h"
 #include "identity.h"

Modified: gnunet/src/identity/identity_api.c
===================================================================
--- gnunet/src/identity/identity_api.c  2013-07-14 19:15:32 UTC (rev 28020)
+++ gnunet/src/identity/identity_api.c  2013-07-14 19:25:22 UTC (rev 28021)
@@ -20,8 +20,8 @@
 
 /**
  * @file identity/identity_api.c
- * @brief api to get information from the network size estimation service
- * @author Nathan Evans
+ * @brief api to interact with the identity service
+ * @author Christian Grothoff
  */
 #include "platform.h"
 #include "gnunet_client_lib.h"
@@ -38,9 +38,9 @@
 #define LOG(kind,...) GNUNET_log_from (kind, "identity-api",__VA_ARGS__)
 
 /** 
  * Handle for a pseudonym.
  */
-struct GNUNET_IDENTITY_Pseudonym
+struct GNUNET_IDENTITY_Ego
 {
 };
 
@@ -222,13 +222,13 @@
 
 
 /**
  * Obtain the ECC key associated with a pseudonym.
  *
  * @param pseudonym the pseudonym
  * @return associated ECC key, valid as long as the pseudonym is valid
  */
 const struct GNUNET_CRYPTO_EccPrivateKey *
-GNUNET_IDENTITY_pseudonym_get_key (struct GNUNET_IDENTITY_Pseudonym *pseudonym)
+GNUNET_IDENTITY_ego_get_key (struct GNUNET_IDENTITY_Ego *ego)
 {
   return NULL;
 }
@@ -259,7 +259,7 @@
  *
  * @param id identity service to inform
  * @param service_name for which service is an identity set
  * @param pseu new default identity to be set for this service
  * @param cont function to call once the operation finished
  * @param cont_cls closure for cont
  * @return handle to abort the operation
@@ -267,7 +267,7 @@
 struct GNUNET_IDENTITY_Operation *
 GNUNET_IDENTITY_set (struct GNUNET_IDENTITY_Handle *id,
                     const char *service_name,
-                    struct GNUNET_IDENTITY_Pseudonym *pseu,
+                    struct GNUNET_IDENTITY_Ego *ego,
                     GNUNET_IDENTITY_Continuation cont,
                     void *cont_cls)
 {

Modified: gnunet/src/include/gnunet_identity_service.h
===================================================================
--- gnunet/src/include/gnunet_identity_service.h        2013-07-14 19:15:32 UTC 
(rev 28020)
+++ gnunet/src/include/gnunet_identity_service.h        2013-07-14 19:25:22 UTC 
(rev 28021)
@@ -25,9 +25,9 @@
  *
  * Identities in GNUnet are ECDSA keys.  You assume an identity by
  * using (signing with) a particular private key.  As GNUnet users are
- * expected to have many pseudonyms, we need an identity service to
- * allow users to manage their pseudonyms.  The identity service
- * manages the pseudonyms (private keys) of the local user; it does
+ * expected to have many egos, we need an identity service to
+ * allow users to manage their egos.  The identity service
+ * manages the egos (private keys) of the local user; it does
  * NOT manage identities of other users (public keys).  For giving
  * names to other users and manage their public keys securely, we
  * use GADS/GNS.
@@ -57,58 +57,58 @@
 struct GNUNET_IDENTITY_Handle;
 
 /** 
  * Handle for a pseudonym.
  */
-struct GNUNET_IDENTITY_Pseudonym;
+struct GNUNET_IDENTITY_Ego;
 
 
 /**
  * Obtain the ECC key associated with a pseudonym.
  *
  * @param pseudonym the pseudonym
  * @return associated ECC key, valid as long as the pseudonym is valid
  */
 const struct GNUNET_CRYPTO_EccPrivateKey *
-GNUNET_IDENTITY_pseudonym_get_key (struct GNUNET_IDENTITY_Pseudonym 
*pseudonym);
+GNUNET_IDENTITY_ego_get_key (struct GNUNET_IDENTITY_Ego *ego);
 
 
 /** 
- * Method called to inform about the pseudonyms of
+ * Method called to inform about the egos of
  * this peer. 
  *
  * When used with 'GNUNET_IDENTITY_connect', this function is
  * initially called for all pseudonyms and then again whenever a
  * pseudonym's identifier changes or if it is deleted.  At the end of
  * the initial pass over all pseudonyms, the function is once called
  * with 'NULL' for 'pseu'. That does NOT mean that the callback won't
  * be invoked in the future or that there was an error.
  *
  * When used with 'GNUNET_IDENTITY_create' or 'GNUNET_IDENTITY_get',
  * this function is only called ONCE, and 'NULL' being passed in
  * 'pseu' does indicate an error (i.e. name is taken or no default
  * value is known).  If 'pseu' is non-NULL and if '*ctx'
  * is set in those callbacks, the value WILL be passed to a subsequent
  * call to the identity callback of 'GNUNET_IDENTITY_connect' (if 
  * that one was not NULL).
  *
  * When an identity is renamed, this function is called with the
  * (known) pseudonym but the NEW identifier.  
  *
  * When an identity is deleted, this function is called with the
  * (known) pseudonym and "NULL" for the 'identifier'.  In this case,
  * the 'pseu' is henceforth invalid (and the 'ctx' should also be
  * cleaned up).
  *
  * @param cls closure
  * @param pseu pseudonym handle
  * @param pseu_ctx context for application to store data for this pseudonym
  *                 (during the lifetime of this process, initially NULL)
  * @param identifier identifier assigned by the user for this pseudonym,
  *                   NULL if the user just deleted the pseudonym and it
  *                   must thus no longer be used
  */
 typedef void (*GNUNET_IDENTITY_Callback)(void *cls,
-                                        struct GNUNET_IDENTITY_Pseudonym *pseu,
+                                        struct GNUNET_IDENTITY_Ego *ego,
                                         void **ctx,
                                         const char *identifier);
 
@@ -160,7 +160,7 @@
  *
  * @param id identity service to inform
  * @param service_name for which service is an identity set
  * @param pseu new default identity to be set for this service
  * @param cont function to call once the operation finished
  * @param cont_cls closure for cont
  * @return handle to abort the operation
@@ -168,7 +168,7 @@
 struct GNUNET_IDENTITY_Operation *
 GNUNET_IDENTITY_set (struct GNUNET_IDENTITY_Handle *id,
                     const char *service_name,
-                    struct GNUNET_IDENTITY_Pseudonym *pseu,
+                    struct GNUNET_IDENTITY_Ego *ego,
                     GNUNET_IDENTITY_Continuation cont,
                     void *cont_cls);
 
@@ -38,9 +38,9 @@
 
 /** 
- * Handle for a pseudonym.
+ * Handle for a ego.
  */
@@ -222,13 +222,13 @@
 
 /**
- * Obtain the ECC key associated with a pseudonym.
+ * Obtain the ECC key associated with a ego.
  *
@@ -222,13 +222,13 @@
  *
- * @param pseudonym the pseudonym
- * @return associated ECC key, valid as long as the pseudonym is valid
+ * @param ego the ego
+ * @return associated ECC key, valid as long as the ego is valid
  */
 const struct GNUNET_CRYPTO_EccPrivateKey *
@@ -259,7 +259,7 @@
  * @param id identity service to inform
  * @param service_name for which service is an identity set
- * @param pseu new default identity to be set for this service
+ * @param ego new default identity to be set for this service
  * @param cont function to call once the operation finished
  * @param cont_cls closure for cont
@@ -57,58 +57,58 @@
 
 /** 
- * Handle for a pseudonym.
+ * Handle for a ego.
  */
@@ -57,58 +57,58 @@
 
 /**
- * Obtain the ECC key associated with a pseudonym.
+ * Obtain the ECC key associated with a ego.
  *
@@ -57,58 +57,58 @@
  *
- * @param pseudonym the pseudonym
- * @return associated ECC key, valid as long as the pseudonym is valid
+ * @param ego the ego
+ * @return associated ECC key, valid as long as the ego is valid
  */
 const struct GNUNET_CRYPTO_EccPrivateKey *
@@ -57,58 +57,58 @@
  *
  * When used with 'GNUNET_IDENTITY_connect', this function is
- * initially called for all pseudonyms and then again whenever a
- * pseudonym's identifier changes or if it is deleted.  At the end of
- * the initial pass over all pseudonyms, the function is once called
- * with 'NULL' for 'pseu'. That does NOT mean that the callback won't
+ * initially called for all egos and then again whenever a
+ * ego's identifier changes or if it is deleted.  At the end of
+ * the initial pass over all egos, the function is once called
+ * with 'NULL' for 'ego'. That does NOT mean that the callback won't
  * be invoked in the future or that there was an error.
  *
@@ -57,58 +57,58 @@
  * When used with 'GNUNET_IDENTITY_create' or 'GNUNET_IDENTITY_get',
  * this function is only called ONCE, and 'NULL' being passed in
- * 'pseu' does indicate an error (i.e. name is taken or no default
- * value is known).  If 'pseu' is non-NULL and if '*ctx'
+ * 'ego' does indicate an error (i.e. name is taken or no default
+ * value is known).  If 'ego' is non-NULL and if '*ctx'
  * is set in those callbacks, the value WILL be passed to a subsequent
  * call to the identity callback of 'GNUNET_IDENTITY_connect' (if 
@@ -57,58 +57,58 @@
  *
  * When an identity is renamed, this function is called with the
- * (known) pseudonym but the NEW identifier.  
+ * (known) ego but the NEW identifier.  
  *
  * When an identity is deleted, this function is called with the
@@ -57,58 +57,58 @@
  *
  * When an identity is deleted, this function is called with the
- * (known) pseudonym and "NULL" for the 'identifier'.  In this case,
- * the 'pseu' is henceforth invalid (and the 'ctx' should also be
+ * (known) ego and "NULL" for the 'identifier'.  In this case,
+ * the 'ego' is henceforth invalid (and the 'ctx' should also be
  * cleaned up).
  *
@@ -57,58 +57,58 @@
  *
  * @param cls closure
- * @param pseu pseudonym handle
- * @param pseu_ctx context for application to store data for this pseudonym
+ * @param ego ego handle
+ * @param ego_ctx context for application to store data for this ego
  *                 (during the lifetime of this process, initially NULL)
@@ -57,58 +57,58 @@
  *                 (during the lifetime of this process, initially NULL)
- * @param identifier identifier assigned by the user for this pseudonym,
- *                   NULL if the user just deleted the pseudonym and it
+ * @param identifier identifier assigned by the user for this ego,
+ *                   NULL if the user just deleted the ego and it
  *                   must thus no longer be used
  */
@@ -160,7 +160,7 @@
  * @param id identity service to inform
  * @param service_name for which service is an identity set
- * @param pseu new default identity to be set for this service
+ * @param ego new default identity to be set for this service
  * @param cont function to call once the operation finished
  * @param cont_cls closure for cont




reply via email to

[Prev in Thread] Current Thread [Next in Thread]